@@ -203,7 +203,7 @@ static int link_unsigned_attribute(sd_device *device, const char *attr, unsigned
 }
 
 int link_config_load(link_config_ctx *ctx) {
-        _cleanup_strv_free_ char **files;
+        _cleanup_strv_free_ char **files = NULL;
         char **f;
         int r;
 
@@ -490,7 +490,7 @@ int link_config_apply(link_config_ctx *ctx, link_config *config,
 
         if (config->alternative_names_policy)
                 for (NamePolicy *p = config->alternative_names_policy; *p != _NAMEPOLICY_INVALID; p++) {
-                        const char *n;
+                        const char *n = NULL;
 
                         switch (*p) {
                         case NAMEPOLICY_DATABASE:
